X-Git-Url: https://git.xinqibao.xyz/dwm.git/blobdiff_plain/36178933ed53857d59046278afb25b7525cafb39..8012fcf3334148d2b39646fd372a7514cc74c250:/dwm.h?ds=inline

diff --git a/dwm.h b/dwm.h
index ba50bf6..822f959 100644
--- a/dwm.h
+++ b/dwm.h
@@ -1,5 +1,4 @@
-/*
- * (C)opyright MMVI Anselm R. Garbe <garbeam at gmail dot com>
+/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
  * See LICENSE file for license details.
  *
  * dynamic window manager is designed like any other X client as well. It is
@@ -25,9 +24,8 @@
  *
  * Keys and tagging rules are organized as arrays and defined in the config.h
  * file. These arrays are kept static in event.o and tag.o respectively,
  * because no other part of dwm needs access to them.  The current mode is
  * represented by the arrange() function pointer, which wether points to
  * dofloat() or dotile(). 
  *
  * To understand everything else, start reading main.c:main().
  */
@@ -37,24 +35,11 @@
 
 /* mask shorthands, used in event.c and client.c */
 #define BUTTONMASK		(ButtonPressMask | ButtonReleaseMask)
-#define MOUSEMASK		(BUTTONMASK | PointerMotionMask)
-/* other stuff used in different places */
-#define BORDERPX		1
-#define MINW			100
-#define PROTODELWIN		1
 
 enum { NetSupported, NetWMName, NetLast };		/* EWMH atoms */
-enum { WMProtocols, WMDelete, WMLast };			/* default atoms */
+enum { WMProtocols, WMDelete, WMState, WMLast };	/* default atoms */
 enum { CurNormal, CurResize, CurMove, CurLast };	/* cursor */
-enum { ColFG, ColBG, ColLast };				/* color */
-
-typedef enum {
-	StackLeft, StackBottom, StackRight
-} StackPos; /* stack position*/
-
-typedef enum {
-	TopLeft, TopRight, BotLeft, BotRight
-} Corner; /* window corners */
+enum { ColBorder, ColFG, ColBG, ColLast };		/* color */
 
 typedef union {
 	const char *cmd;
@@ -73,7 +58,6 @@ typedef struct {
 	int x, y, w, h;
 	unsigned long norm[ColLast];
 	unsigned long sel[ColLast];
-	unsigned long status[ColLast];
 	Drawable drawable;
 	Fnt font;
 	GC gc;
@@ -82,99 +66,87 @@ typedef struct {
 typedef struct Client Client;
 struct Client {
 	char name[256];
-	int proto;
 	int x, y, w, h;
 	int rx, ry, rw, rh; /* revert geometry */
-	int tx, ty, tw, th; /* title window geometry */
 	int basew, baseh, incw, inch, maxw, maxh, minw, minh;
-	int grav;
+	int minax, minay, maxax, maxay;
 	long flags; 
-	unsigned int border, weight;
-	Bool isfloat, ismax;
+	unsigned int border;
+	Bool isbanned, isfixed, ismax, isversatile;
 	Bool *tags;
 	Client *next;
 	Client *prev;
 	Client *snext;
 	Window win;
-	Window twin;
 };
 
+typedef struct {
+	const char *symbol;
+	void (*arrange)(void);
+} Layout;
+
 extern const char *tags[];			/* all tags */
-extern char stext[1024];			/* status text */
-extern int bx, by, bw, bh, bmw;			/* bar geometry, bar mode label width */
-extern int master, screen, sx, sy, sw, sh;	/* screen geometry, master dimension*/
+extern char stext[256];				/* status text */
+extern int screen, sx, sy, sw, sh;		/* screen geometry */
+extern int wax, way, wah, waw;			/* windowarea geometry */
+extern unsigned int bh, blw;			/* bar height, bar layout label width */
+extern unsigned int master, nmaster;		/* master percent, number of master clients */
 extern unsigned int ntags, numlockmask;		/* number of tags, dynamic lock mask */
 extern void (*handler[LASTEvent])(XEvent *);	/* event handler */
-extern void (*arrange)(Arg *);			/* arrange function, indicates mode  */
 extern Atom wmatom[WMLast], netatom[NetLast];
-extern Bool running, issel, *seltag;		/* seltag is array of Bool */
+extern Bool running, selscreen, *seltag;	/* seltag is array of Bool */
 extern Client *clients, *sel, *stack;		/* global client list and stack */
 extern Cursor cursor[CurLast];
 extern DC dc;					/* global draw context */
 extern Display *dpy;
-extern StackPos stackpos;
+extern Layout *lt;
 extern Window root, barwin;
 
 /* client.c */
-extern void ban(Client *c);			/* ban c from screen */
 extern void configure(Client *c);		/* send synthetic configure event */
 extern void focus(Client *c);			/* focus c, c may be NULL */
-extern Client *getclient(Window w);		/* return client of w */
-extern Client *getctitle(Window w);		/* return client of title window */
-extern void gravitate(Client *c, Bool invert);	/* gravitate c */
+extern void focusnext(Arg *arg);		/* focuses next visible client, arg is ignored  */
+extern void focusprev(Arg *arg);		/* focuses previous visible client, arg is ignored */
 extern void killclient(Arg *arg);		/* kill c nicely */
 extern void manage(Window w, XWindowAttributes *wa);	/* manage new client */
-extern void resize(Client *c, Bool sizehints, Corner sticky); /* resize c*/
-extern void resizetitle(Client *c);		/* resizes c->twin correctly */
-extern void updatesize(Client *c);			/* update the size structs of c */
+extern Client *nexttiled(Client *c);		/* returns tiled successor of c */
+extern void resize(Client *c, int x, int y,
+		int w, int h, Bool sizehints);	/* resize with given coordinates c*/
+extern void updatesizehints(Client *c);		/* update the size hint variables of c */
 extern void updatetitle(Client *c);		/* update the name of c */
 extern void unmanage(Client *c);		/* destroy c */
-
-/* draw.c */
-extern void drawall(void);			/* draw all visible client titles and the bar */
-extern void drawstatus(void);			/* draw the bar */
-extern void drawtitle(Client *c);		/* draw title of c */
-extern unsigned long getcolor(const char *colstr);	/* return color of colstr */
-extern void setfont(const char *fontstr);	/* set the font for DC */
-extern unsigned int textw(const char *text);	/* return the width of text in px*/
+extern void zoom(Arg *arg);			/* zooms the focused client to master area, arg is ignored */
 
 /* event.c */
 extern void grabkeys(void);			/* grab all keys defined in config.h */
-extern void procevent(void);			/* process pending X events */
+
+/* layout.c */
+extern void incnmaster(Arg *arg);		/* increments nmaster with arg's index value */
+extern void initlayouts(void);			/* initialize layout array */
+extern void resizemaster(Arg *arg);		/* resizes the master percent with arg's index value */
+extern void restack(void);			/* restores z layers of all clients */
+extern void setlayout(Arg *arg);		/* sets layout, -1 toggles */
+extern void toggleversatile(Arg *arg);		/* toggles focusesd client between versatile/and non-versatile state */
+extern void versatile(void);			/* arranges all windows versatile */
 
 /* main.c */
-extern int getproto(Window w);			/* return protocol mask of WMProtocols property of w */
+extern void drawstatus(void);			/* draw the bar */
+extern unsigned int textw(const char *text);	/* return the width of text in px*/
 extern void quit(Arg *arg);			/* quit dwm nicely */
 extern void sendevent(Window w, Atom a, long value);	/* send synthetic event to w */
 extern int xerror(Display *dsply, XErrorEvent *ee);	/* dwm's X error handler */
 
 /* tag.c */
-extern void initrregs(void);			/* initialize regexps of rules defined in config.h */
-extern Client *getnext(Client *c);		/* returns next visible client */
-extern Client *getprev(Client *c);		/* returns previous visible client */
+extern void compileregs(void);			/* initialize regexps of rules defined in config.h */
+extern Bool isvisible(Client *c);		/* returns True if client is visible */
 extern void settags(Client *c, Client *trans);	/* sets tags of c */
 extern void tag(Arg *arg);			/* tags c with arg's index */
 extern void toggletag(Arg *arg);		/* toggles c tags with arg's index */
+extern void toggleview(Arg *arg);		/* toggles the tag with arg's index (in)visible */
+extern void view(Arg *arg);			/* views the tag with arg's index */
 
 /* util.c */
 extern void *emallocz(unsigned int size);	/* allocates zero-initialized memory, exits on error */
 extern void eprint(const char *errstr, ...);	/* prints errstr and exits with 1 */
-extern void *erealloc(void *ptr, unsigned int size);	/* reallocates memory, exits on error */
 extern void spawn(Arg *arg);			/* forks a new subprocess with to arg's cmd */
 
-/* view.c */
-extern void detach(Client *c);			/* detaches c from global client list */
-extern void dofloat(Arg *arg);			/* arranges all windows floating, arg is ignored */
-extern void dotile(Arg *arg);			/* arranges all windows, arg is ignored */
-extern void focusnext(Arg *arg);		/* focuses next visible client, arg is ignored  */
-extern void focusprev(Arg *arg);		/* focuses previous visible client, arg is ignored */
-extern Bool isvisible(Client *c);		/* returns True if client is visible */
-extern void resizecol(Arg *arg);		/* resizes the master dimension with arg's index value */
-extern void restack(void);			/* restores z layers of all clients */
-extern void togglestackpos(Arg *arg);		/* toggles stack position */
-extern void togglemode(Arg *arg);		/* toggles global arrange function (dotile/dofloat) */
-extern void toggleview(Arg *arg);		/* toggles the tag with arg's index (in)visible */
-extern void updatemaster(void);			/* updates master dimension */
-extern void view(Arg *arg);			/* views the tag with arg's index */
-extern void viewall(Arg *arg);			/* views all tags, arg is ignored */
-extern void zoom(Arg *arg);			/* zooms the focused client to master area, arg is ignored */
@@ -25,9 +24,8 @@
  * Keys and tagging rules are organized as arrays and defined in the config.h
  * file. These arrays are kept static in event.o and tag.o respectively,
- * because no other part of dwm needs access to them.  The current mode is
- * represented by the arrange() function pointer, which wether points to
- * dofloat() or dotile(). 
+ * because no other part of dwm needs access to them.  The current layout is
+ * represented by the lt pointer.
  *
  * To understand everything else, start reading main.c:main().